//!OpenSCAD

Width = 3;
Depth = 1.75;
Thickness = 0.375;
Angle = 15;
Endmill_Diameter = 0.25;
Units = 25.4; // [1:millimeters, 25.4:Inches]
$fn = 80;

cdiameter = (Endmill_Diameter * Units) * 1.1;
radius = cdiameter / 2;
cwidth = Width * Units;
cdepth = Depth * Units;
cthickness = Thickness * Units;
coffsetx = radius * sin(Angle);
coffsety = coffsetx * tan(Angle);

module makequarter() {
  difference() {
    union(){
      hull(){
        translate([radius, radius, 0]){
          cylinder(r1=radius, r2=radius, h=cthickness, center=false);
        }
        translate([radius, (cdepth - cdiameter), 0]){
          cylinder(r1=radius, r2=radius, h=cthickness, center=false);
        }
        translate([radius, ((cwidth / 2 - (radius + coffsetx)) * tan(Angle)), 0]){
          cube([(cwidth / 2 - radius), (cdepth / 3), cthickness], center=false);
        }
      }
      translate([(cwidth / 2 - radius), ((cwidth / 2 - (radius + coffsetx)) * tan(Angle) - coffsety), 0]){
        cube([cdiameter, (cdepth / 3), (cthickness * 1)], center=false);
      }
    }

    union(){
      translate([(cwidth / 2), ((cwidth / 2 - (radius + coffsetx)) * tan(Angle) - (radius + coffsety / 2)), (-(cthickness * 0.1))]){
        cylinder(r1=radius, r2=radius, h=(cthickness * 1.2), center=false);
      }
      translate([(cwidth / 2), (cdepth - ((cwidth / 2 - (radius + coffsetx)) * tan(Angle) - (radius + coffsety / 2))), (-(cthickness * 0.1))]){
        cylinder(r1=radius, r2=radius, h=(cthickness * 1.2), center=false);
      }
    }
  }
}

module makehalf() {
  union(){
    makequarter();
    translate([0, cdepth, 0]){
      mirror([0,1,0]){
        makequarter();
      }
    }
  }
}

projection(){
union(){
  makehalf();
  translate([cwidth, 0, 0]){
    mirror([1,0,0]){
      makehalf();
    }
  }
}
}
